"""A modification workflow for setting a new :term:`ISIS` metric for an IP trunk."""

from orchestrator.targets import Target
from orchestrator.types import State, UUIDstr
from orchestrator.workflow import StepList, done, init, step, workflow
from orchestrator.workflows.steps import resync, store_process_subscription, unsync
from orchestrator.workflows.utils import wrap_modify_initial_input_form

from gso.products import ProductName
from gso.products.product_types.router import ImportedRouter, Router
from gso.services.subscriptions import get_product_id_by_name


@step("Create new router subscription")
def import_router_subscription(subscription_id: UUIDstr) -> State:
    """Take an ImportedRouter subscription, and turn it into a Router subscription."""
    old_router = ImportedRouter.from_subscription(subscription_id)
    new_subscription_id = get_product_id_by_name(ProductName.SITE)
    new_subscription = Router.from_other_product(old_router, new_subscription_id)

    return {"subscription": new_subscription}


@workflow("Import Router", target=Target.MODIFY, initial_input_form=wrap_modify_initial_input_form(None))
def import_router() -> StepList:
    """Modify an ImportedRouter subscription into a Router subscription to complete the import."""
    return init >> store_process_subscription(Target.MODIFY) >> unsync >> import_router_subscription >> resync >> done
